@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.6.1.  */
+/* A Bison parser, made by GNU Bison 3.0.2.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2012 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,13 +26,13 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_PARSER_H
-# define YY_PARSER_H
-/* Enabling traces.  */
+#ifndef YY_YY_PARSER_H_INCLUDED
+# define YY_YY_PARSER_H_INCLUDED
+/* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
 #endif
@@ -40,24 +40,23 @@
 extern int yydebug;
 #endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     T_VIRTUAL = 258,
-     T_DISPLAY = 259,
-     T_WALL = 260,
-     T_OPTION = 261,
-     T_PARAM = 262,
-     T_STRING = 263,
-     T_DIMENSION = 264,
-     T_OFFSET = 265,
-     T_ORIGIN = 266,
-     T_COMMENT = 267,
-     T_LINE_COMMENT = 268
-   };
+  enum yytokentype
+  {
+    T_VIRTUAL = 258,
+    T_DISPLAY = 259,
+    T_WALL = 260,
+    T_OPTION = 261,
+    T_PARAM = 262,
+    T_STRING = 263,
+    T_DIMENSION = 264,
+    T_OFFSET = 265,
+    T_ORIGIN = 266,
+    T_COMMENT = 267,
+    T_LINE_COMMENT = 268
+  };
 #endif
 /* Tokens.  */
 #define T_VIRTUAL 258
@@ -72,13 +71,12 @@ extern int yydebug;
 #define T_COMMENT 267
 #define T_LINE_COMMENT 268
 
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+typedef union YYSTYPE YYSTYPE;
+union YYSTYPE
 {
-/* Line 2049 of yacc.c  */
-#line 56 "parser.y"
+#line 56 "../../../../hw/dmx/config/parser.y" /* yacc.c:1909  */
 
     DMXConfigTokenPtr      token;
     DMXConfigStringPtr     string;
@@ -95,29 +93,15 @@ typedef union YYSTYPE
     DMXConfigVirtualPtr    virtual;
     DMXConfigEntryPtr      entry;
 
-
-/* Line 2049 of yacc.c  */
-#line 101 "parser.h"
-} YYSTYPE;
+#line 97 "parser.h" /* yacc.c:1909  */
+};
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE yylval;
 
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int yyparse (void *YYPARSE_PARAM);
-#else
-int yyparse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
 int yyparse (void);
-#else
-int yyparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
-#endif /* !YY_PARSER_H  */
+#endif /* !YY_YY_PARSER_H_INCLUDED  */
