@@ -47,10 +47,10 @@
 #include "vidmodeproc.h"
 #include "xf86cmap.h"
 
-static int VidModeKeyIndex;
+static DevPrivateKeyRec VidModeKeyRec;
 static DevPrivateKey VidModeKey;
 static int VidModeCount = 0;
-static Bool VidModeClose(int i, ScreenPtr pScreen);
+static Bool VidModeClose(ScreenPtr pScreen);
 
 #define VMPTR(p) ((VidModePtr)dixLookupPrivate(&(p)->devPrivates, VidModeKey))
 
@@ -61,21 +61,23 @@ VidModeExtensionInit(ScreenPtr pScreen)
 {
 #ifdef XF86VIDMODE
     VidModePtr pVidMode;
-    
+
     if (!xf86GetVidModeEnabled()) {
-	DebugF("!xf86GetVidModeEnabled()\n");
-	return FALSE;
+        DebugF("!xf86GetVidModeEnabled()\n");
+        return FALSE;
     }
 
-    VidModeKey = &VidModeKeyIndex;
+    VidModeKey = &VidModeKeyRec;
 
-    if (!dixSetPrivate(&pScreen->devPrivates, VidModeKey,
-		       xcalloc(sizeof(VidModeRec), 1))) {
-	DebugF("xcalloc failed\n");
-	return FALSE;
-    }
+    if (!dixRegisterPrivateKey(&VidModeKeyRec, PRIVATE_SCREEN, 0))
+        return FALSE;
+
+    pVidMode = calloc(sizeof(VidModeRec), 1);
+    if (!pVidMode)
+        return FALSE;
+
+    dixSetPrivate(&pScreen->devPrivates, VidModeKey, pVidMode);
 
-    pVidMode = VMPTR(pScreen);
     pVidMode->Flags = 0;
     pVidMode->Next = NULL;
     pVidMode->CloseScreen = pScreen->CloseScreen;
@@ -88,26 +90,25 @@ VidModeExtensionInit(ScreenPtr pScreen)
 #endif
 }
 
-
 #ifdef XF86VIDMODE
 
 static Bool
-VidModeClose(int i, ScreenPtr pScreen)
+VidModeClose(ScreenPtr pScreen)
 {
     VidModePtr pVidMode = VMPTR(pScreen);
 
     /* This shouldn't happen */
     if (!pVidMode)
-	return FALSE;
+        return FALSE;
 
     pScreen->CloseScreen = pVidMode->CloseScreen;
 
     if (--VidModeCount == 0) {
-	xfree(dixLookupPrivate(&pScreen->devPrivates, VidModeKey));
-	dixSetPrivate(&pScreen->devPrivates, VidModeKey, NULL);
-	VidModeKey = NULL;
+        free(dixLookupPrivate(&pScreen->devPrivates, VidModeKey));
+        dixSetPrivate(&pScreen->devPrivates, VidModeKey, NULL);
+        VidModeKey = NULL;
     }
-    return pScreen->CloseScreen(i, pScreen);
+    return pScreen->CloseScreen(pScreen);
 }
 
 Bool
@@ -117,40 +118,40 @@ VidModeAvailable(int scrnIndex)
     VidModePtr pVidMode;
 
     if (VidModeKey == NULL) {
-	DebugF("VidModeKey == NULL\n");
-	return FALSE;
+        DebugF("VidModeKey == NULL\n");
+        return FALSE;
     }
- 
+
     pScrn = xf86Screens[scrnIndex];
     if (pScrn == NULL) {
-	DebugF("pScrn == NULL\n");
-	return FALSE;
+        DebugF("pScrn == NULL\n");
+        return FALSE;
     }
-    
+
     pVidMode = VMPTR(pScrn->pScreen);
     if (pVidMode)
-	return TRUE;
+        return TRUE;
     else {
-	DebugF("pVidMode == NULL\n");
-	return FALSE;
+        DebugF("pVidMode == NULL\n");
+        return FALSE;
     }
 }
 
 Bool
-VidModeGetCurrentModeline(int scrnIndex, pointer *mode, int *dotClock)
+VidModeGetCurrentModeline(int scrnIndex, void **mode, int *dotClock)
 {
     ScrnInfoPtr pScrn;
 
     if (!VidModeAvailable(scrnIndex))
-	return FALSE;
+        return FALSE;
 
     pScrn = xf86Screens[scrnIndex];
 
     if (pScrn->currentMode) {
-	*mode = (pointer)(pScrn->currentMode);
-	*dotClock = pScrn->currentMode->Clock;
+        *mode = (void *) (pScrn->currentMode);
+        *dotClock = pScrn->currentMode->Clock;
 
-	return TRUE;
+        return TRUE;
     }
     return FALSE;
 }
@@ -161,13 +162,13 @@ VidModeGetDotClock(int scrnIndex, int Clock)
     ScrnInfoPtr pScrn;
 
     if (!VidModeAvailable(scrnIndex))
-	return 0;
+        return 0;
 
     pScrn = xf86Screens[scrnIndex];
     if ((pScrn->progClock) || (Clock >= MAXCLOCKS))
-	return Clock;
-    else  
-	return pScrn->clock[Clock];
+        return Clock;
+    else
+        return pScrn->clock[Clock];
 }
 
 int
@@ -176,15 +177,16 @@ VidModeGetNumOfClocks(int scrnIndex, Bool *progClock)
     ScrnInfoPtr pScrn;
 
     if (!VidModeAvailable(scrnIndex))
-	return 0;
+        return 0;
 
     pScrn = xf86Screens[scrnIndex];
-    if (pScrn->progClock){
-	*progClock = TRUE;
-	return 0;
-    } else {
-	*progClock = FALSE;
-	return pScrn->numClocks;
+    if (pScrn->progClock) {
+        *progClock = TRUE;
+        return 0;
+    }
+    else {
+        *progClock = FALSE;
+        return pScrn->numClocks;
     }
 }
 
@@ -195,78 +197,80 @@ VidModeGetClocks(int scrnIndex, int *Clocks)
     int i;
 
     if (!VidModeAvailable(scrnIndex))
-	return FALSE;
+        return FALSE;
 
     pScrn = xf86Screens[scrnIndex];
 
     if (pScrn->progClock)
-	return FALSE;
+        return FALSE;
 
-    for (i = 0;  i < pScrn->numClocks;  i++)
-	*Clocks++ = pScrn->clock[i];
+    for (i = 0; i < pScrn->numClocks; i++)
+        *Clocks++ = pScrn->clock[i];
 
     return TRUE;
 }
 
-
 Bool
-VidModeGetFirstModeline(int scrnIndex, pointer *mode, int *dotClock)
+VidModeGetFirstModeline(int scrnIndex, void **mode, int *dotClock)
 {
     ScrnInfoPtr pScrn;
     VidModePtr pVidMode;
 
     if (!VidModeAvailable(scrnIndex))
-	return FALSE;
+        return FALSE;
 
     pScrn = xf86Screens[scrnIndex];
+    if (pScrn->modes == NULL)
+        return FALSE;
+
     pVidMode = VMPTR(pScrn->pScreen);
     pVidMode->First = pScrn->modes;
-    pVidMode->Next =  pVidMode->First->next;
+    pVidMode->Next = pVidMode->First->next;
 
     if (pVidMode->First->status == MODE_OK) {
-      *mode = (pointer)(pVidMode->First);
-      *dotClock = VidModeGetDotClock(scrnIndex, pVidMode->First->Clock);
-      return TRUE;
+        *mode = (void *) (pVidMode->First);
+        *dotClock = VidModeGetDotClock(scrnIndex, pVidMode->First->Clock);
+        return TRUE;
     }
 
     return VidModeGetNextModeline(scrnIndex, mode, dotClock);
 }
 
 Bool
-VidModeGetNextModeline(int scrnIndex, pointer *mode, int *dotClock)
+VidModeGetNextModeline(int scrnIndex, void **mode, int *dotClock)
 {
     ScrnInfoPtr pScrn;
     VidModePtr pVidMode;
     DisplayModePtr p;
 
     if (!VidModeAvailable(scrnIndex))
-	return FALSE;
+        return FALSE;
 
     pScrn = xf86Screens[scrnIndex];
     pVidMode = VMPTR(pScrn->pScreen);
 
     for (p = pVidMode->Next; p != NULL && p != pVidMode->First; p = p->next) {
-	if (p->status == MODE_OK) {
-	    pVidMode->Next = p->next;
-	    *mode = (pointer)p;
-	    *dotClock = VidModeGetDotClock(scrnIndex, p->Clock);
-	    return TRUE;
-	}
+        if (p->status == MODE_OK) {
+            pVidMode->Next = p->next;
+            *mode = (void *) p;
+            *dotClock = VidModeGetDotClock(scrnIndex, p->Clock);
+            return TRUE;
+        }
     }
-    
+
     return FALSE;
 }
 
 Bool
-VidModeDeleteModeline(int scrnIndex, pointer mode)
+VidModeDeleteModeline(int scrnIndex, void *mode)
 {
     ScrnInfoPtr pScrn;
 
     if ((mode == NULL) || (!VidModeAvailable(scrnIndex)))
-	return FALSE;
+        return FALSE;
 
     pScrn = xf86Screens[scrnIndex];
-    xf86DeleteMode(&(pScrn->modes), (DisplayModePtr)mode);
+    xf86DeleteMode(&(pScrn->modes), (DisplayModePtr) mode);
     return TRUE;
 }
 
@@ -276,7 +280,7 @@ VidModeZoomViewport(int scrnIndex, int zoom)
     ScrnInfoPtr pScrn;
 
     if (!VidModeAvailable(scrnIndex))
-	return FALSE;
+        return FALSE;
 
     pScrn = xf86Screens[scrnIndex];
     xf86ZoomViewport(pScrn->pScreen, zoom);
@@ -289,17 +293,17 @@ VidModeSetViewPort(int scrnIndex, int x, int y)
     ScrnInfoPtr pScrn;
 
     if (!VidModeAvailable(scrnIndex))
-	return FALSE;
+        return FALSE;
 
     pScrn = xf86Screens[scrnIndex];
-    pScrn->frameX0 = min( max(x, 0),
-	                 pScrn->virtualX - pScrn->currentMode->HDisplay );
+    pScrn->frameX0 = min(max(x, 0),
+                         pScrn->virtualX - pScrn->currentMode->HDisplay);
     pScrn->frameX1 = pScrn->frameX0 + pScrn->currentMode->HDisplay - 1;
-    pScrn->frameY0 = min( max(y, 0),
-	                 pScrn->virtualY - pScrn->currentMode->VDisplay );
+    pScrn->frameY0 = min(max(y, 0),
+                         pScrn->virtualY - pScrn->currentMode->VDisplay);
     pScrn->frameY1 = pScrn->frameY0 + pScrn->currentMode->VDisplay - 1;
     if (pScrn->AdjustFrame != NULL)
-	(pScrn->AdjustFrame)(scrnIndex, pScrn->frameX0, pScrn->frameY0, 0);
+        (pScrn->AdjustFrame) (pScrn, pScrn->frameX0, pScrn->frameY0);
 
     return TRUE;
 }
@@ -310,7 +314,7 @@ VidModeGetViewPort(int scrnIndex, int *x, int *y)
     ScrnInfoPtr pScrn;
 
     if (!VidModeAvailable(scrnIndex))
-	return FALSE;
+        return FALSE;
 
     pScrn = xf86Screens[scrnIndex];
     *x = pScrn->frameX0;
@@ -319,14 +323,14 @@ VidModeGetViewPort(int scrnIndex, int *x, int *y)
 }
 
 Bool
-VidModeSwitchMode(int scrnIndex, pointer mode)
+VidModeSwitchMode(int scrnIndex, void *mode)
 {
     ScrnInfoPtr pScrn;
     DisplayModePtr pTmpMode;
     Bool retval;
 
     if (!VidModeAvailable(scrnIndex))
-	return FALSE;
+        return FALSE;
 
     pScrn = xf86Screens[scrnIndex];
     /* save in case we fail */
@@ -336,7 +340,7 @@ VidModeSwitchMode(int scrnIndex, pointer mode)
     retval = xf86SwitchMode(pScrn->pScreen, mode);
     /* we failed: restore it */
     if (retval == FALSE)
-	pScrn->currentMode = pTmpMode;
+        pScrn->currentMode = pTmpMode;
     return retval;
 }
 
@@ -346,93 +350,93 @@ VidModeLockZoom(int scrnIndex, Bool lock)
     ScrnInfoPtr pScrn;
 
     if (!VidModeAvailable(scrnIndex))
-	return FALSE;
+        return FALSE;
 
     pScrn = xf86Screens[scrnIndex];
 
     if (xf86Info.dontZoom)
-	return FALSE;
+        return FALSE;
 
     xf86LockZoom(pScrn->pScreen, lock);
     return TRUE;
 }
 
 Bool
-VidModeGetMonitor(int scrnIndex, pointer *monitor)
+VidModeGetMonitor(int scrnIndex, void **monitor)
 {
     ScrnInfoPtr pScrn;
 
     if (!VidModeAvailable(scrnIndex))
-	return FALSE;
+        return FALSE;
 
     pScrn = xf86Screens[scrnIndex];
-    *monitor = (pointer)(pScrn->monitor);
+    *monitor = (void *) (pScrn->monitor);
 
     return TRUE;
 }
 
 ModeStatus
-VidModeCheckModeForMonitor(int scrnIndex, pointer mode)
+VidModeCheckModeForMonitor(int scrnIndex, void *mode)
 {
     ScrnInfoPtr pScrn;
 
     if ((mode == NULL) || (!VidModeAvailable(scrnIndex)))
-	return MODE_ERROR;
+        return MODE_ERROR;
 
     pScrn = xf86Screens[scrnIndex];
 
-    return xf86CheckModeForMonitor((DisplayModePtr)mode, pScrn->monitor);
+    return xf86CheckModeForMonitor((DisplayModePtr) mode, pScrn->monitor);
 }
 
 ModeStatus
-VidModeCheckModeForDriver(int scrnIndex, pointer mode)
+VidModeCheckModeForDriver(int scrnIndex, void *mode)
 {
     ScrnInfoPtr pScrn;
 
     if ((mode == NULL) || (!VidModeAvailable(scrnIndex)))
-	return MODE_ERROR;
+        return MODE_ERROR;
 
     pScrn = xf86Screens[scrnIndex];
 
-    return xf86CheckModeForDriver(pScrn, (DisplayModePtr)mode, 0);
+    return xf86CheckModeForDriver(pScrn, (DisplayModePtr) mode, 0);
 }
 
 void
-VidModeSetCrtcForMode(int scrnIndex, pointer mode)
+VidModeSetCrtcForMode(int scrnIndex, void *mode)
 {
     ScrnInfoPtr pScrn;
     DisplayModePtr ScreenModes;
-    
+
     if ((mode == NULL) || (!VidModeAvailable(scrnIndex)))
-	return;
+        return;
 
     /* Ugly hack so that the xf86Mode.c function can be used without change */
     pScrn = xf86Screens[scrnIndex];
     ScreenModes = pScrn->modes;
-    pScrn->modes = (DisplayModePtr)mode;
-    
+    pScrn->modes = (DisplayModePtr) mode;
+
     xf86SetCrtcForModes(pScrn, pScrn->adjustFlags);
     pScrn->modes = ScreenModes;
     return;
 }
 
 Bool
-VidModeAddModeline(int scrnIndex, pointer mode)
+VidModeAddModeline(int scrnIndex, void *mode)
 {
     ScrnInfoPtr pScrn;
-    
+
     if ((mode == NULL) || (!VidModeAvailable(scrnIndex)))
-	return FALSE;
+        return FALSE;
 
     pScrn = xf86Screens[scrnIndex];
 
-    ((DisplayModePtr)mode)->name         = strdup(""); /* freed by deletemode */
-    ((DisplayModePtr)mode)->status       = MODE_OK;
-    ((DisplayModePtr)mode)->next         = pScrn->modes->next;
-    ((DisplayModePtr)mode)->prev         = pScrn->modes;
-    pScrn->modes->next                   = (DisplayModePtr)mode;
-    if( ((DisplayModePtr)mode)->next != NULL )
-      ((DisplayModePtr)mode)->next->prev   = (DisplayModePtr)mode;
+    ((DisplayModePtr) mode)->name = strdup(""); /* freed by deletemode */
+    ((DisplayModePtr) mode)->status = MODE_OK;
+    ((DisplayModePtr) mode)->next = pScrn->modes->next;
+    ((DisplayModePtr) mode)->prev = pScrn->modes;
+    pScrn->modes->next = (DisplayModePtr) mode;
+    if (((DisplayModePtr) mode)->next != NULL)
+        ((DisplayModePtr) mode)->next->prev = (DisplayModePtr) mode;
 
     return TRUE;
 }
@@ -440,16 +444,16 @@ VidModeAddModeline(int scrnIndex, pointer mode)
 int
 VidModeGetNumOfModes(int scrnIndex)
 {
-    pointer mode = NULL;
-    int dotClock= 0, nummodes = 0;
-  
+    void *mode = NULL;
+    int dotClock = 0, nummodes = 0;
+
     if (!VidModeGetFirstModeline(scrnIndex, &mode, &dotClock))
-	return nummodes;
+        return nummodes;
 
     do {
-	nummodes++;
-	if (!VidModeGetNextModeline(scrnIndex, &mode, &dotClock))
-	    return nummodes;
+        nummodes++;
+        if (!VidModeGetNextModeline(scrnIndex, &mode, &dotClock))
+            return nummodes;
     } while (TRUE);
 }
 
@@ -460,16 +464,16 @@ VidModeSetGamma(int scrnIndex, float red, float green, float blue)
     Gamma gamma;
 
     if (!VidModeAvailable(scrnIndex))
-	return FALSE;
+        return FALSE;
 
     pScrn = xf86Screens[scrnIndex];
     gamma.red = red;
     gamma.green = green;
     gamma.blue = blue;
     if (xf86ChangeGamma(pScrn->pScreen, gamma) != Success)
-	return FALSE;
+        return FALSE;
     else
-	return TRUE;
+        return TRUE;
 }
 
 Bool
@@ -478,7 +482,7 @@ VidModeGetGamma(int scrnIndex, float *red, float *green, float *blue)
     ScrnInfoPtr pScrn;
 
     if (!VidModeAvailable(scrnIndex))
-	return FALSE;
+        return FALSE;
 
     pScrn = xf86Screens[scrnIndex];
     *red = pScrn->gamma.red;
@@ -494,7 +498,7 @@ VidModeSetGammaRamp(int scrnIndex, int size, CARD16 *r, CARD16 *g, CARD16 *b)
 
     if (!VidModeAvailable(scrnIndex))
         return FALSE;
- 
+
     pScrn = xf86Screens[scrnIndex];
     xf86ChangeGammaRamp(pScrn->pScreen, size, r, g, b);
     return TRUE;
@@ -522,146 +526,144 @@ VidModeGetGammaRampSize(int scrnIndex)
     return xf86GetGammaRampSize(xf86Screens[scrnIndex]->pScreen);
 }
 
-pointer
+void *
 VidModeCreateMode(void)
 {
     DisplayModePtr mode;
-  
-    mode = xalloc(sizeof(DisplayModeRec));
+
+    mode = malloc(sizeof(DisplayModeRec));
     if (mode != NULL) {
-	mode->name          = "";
-	mode->VScan         = 1;    /* divides refresh rate. default = 1 */
-	mode->Private       = NULL;
-	mode->next          = mode;
-	mode->prev          = mode;
+        mode->name = "";
+        mode->VScan = 1;        /* divides refresh rate. default = 1 */
+        mode->Private = NULL;
+        mode->next = mode;
+        mode->prev = mode;
     }
     return mode;
 }
 
 void
-VidModeCopyMode(pointer modefrom, pointer modeto)
+VidModeCopyMode(void *modefrom, void *modeto)
 {
-  memcpy(modeto, modefrom, sizeof(DisplayModeRec));
+    memcpy(modeto, modefrom, sizeof(DisplayModeRec));
 }
 
-
 int
-VidModeGetModeValue(pointer mode, int valtyp)
+VidModeGetModeValue(void *mode, int valtyp)
 {
-  int ret = 0;
-  
-  switch (valtyp) {
+    int ret = 0;
+
+    switch (valtyp) {
     case VIDMODE_H_DISPLAY:
-	ret = ((DisplayModePtr) mode)->HDisplay;
-	break;
+        ret = ((DisplayModePtr) mode)->HDisplay;
+        break;
     case VIDMODE_H_SYNCSTART:
-	ret = ((DisplayModePtr)mode)->HSyncStart;
-	break;
+        ret = ((DisplayModePtr) mode)->HSyncStart;
+        break;
     case VIDMODE_H_SYNCEND:
-	ret = ((DisplayModePtr)mode)->HSyncEnd;
-	break;
+        ret = ((DisplayModePtr) mode)->HSyncEnd;
+        break;
     case VIDMODE_H_TOTAL:
-	ret = ((DisplayModePtr)mode)->HTotal;
-	break;
+        ret = ((DisplayModePtr) mode)->HTotal;
+        break;
     case VIDMODE_H_SKEW:
-	ret = ((DisplayModePtr)mode)->HSkew;
-	break;
+        ret = ((DisplayModePtr) mode)->HSkew;
+        break;
     case VIDMODE_V_DISPLAY:
-	ret = ((DisplayModePtr)mode)->VDisplay;
-	break;
+        ret = ((DisplayModePtr) mode)->VDisplay;
+        break;
     case VIDMODE_V_SYNCSTART:
-	ret = ((DisplayModePtr)mode)->VSyncStart;
-	break;
+        ret = ((DisplayModePtr) mode)->VSyncStart;
+        break;
     case VIDMODE_V_SYNCEND:
-	ret = ((DisplayModePtr)mode)->VSyncEnd;
-	break;
+        ret = ((DisplayModePtr) mode)->VSyncEnd;
+        break;
     case VIDMODE_V_TOTAL:
-	ret = ((DisplayModePtr)mode)->VTotal;
-	break;
+        ret = ((DisplayModePtr) mode)->VTotal;
+        break;
     case VIDMODE_FLAGS:
-	ret = ((DisplayModePtr)mode)->Flags;
-	break;
+        ret = ((DisplayModePtr) mode)->Flags;
+        break;
     case VIDMODE_CLOCK:
-	ret = ((DisplayModePtr)mode)->Clock;
-	break;
-  }
-  return ret;
+        ret = ((DisplayModePtr) mode)->Clock;
+        break;
+    }
+    return ret;
 }
 
 void
-VidModeSetModeValue(pointer mode, int valtyp, int val)
+VidModeSetModeValue(void *mode, int valtyp, int val)
 {
-  switch (valtyp) {
+    switch (valtyp) {
     case VIDMODE_H_DISPLAY:
-	((DisplayModePtr)mode)->HDisplay = val;
-	break;
+        ((DisplayModePtr) mode)->HDisplay = val;
+        break;
     case VIDMODE_H_SYNCSTART:
-	((DisplayModePtr)mode)->HSyncStart = val;
-	break;
+        ((DisplayModePtr) mode)->HSyncStart = val;
+        break;
     case VIDMODE_H_SYNCEND:
-	((DisplayModePtr)mode)->HSyncEnd = val;
-	break;
+        ((DisplayModePtr) mode)->HSyncEnd = val;
+        break;
     case VIDMODE_H_TOTAL:
-	((DisplayModePtr)mode)->HTotal = val;
-	break;
+        ((DisplayModePtr) mode)->HTotal = val;
+        break;
     case VIDMODE_H_SKEW:
-	((DisplayModePtr)mode)->HSkew = val;
-	break;
+        ((DisplayModePtr) mode)->HSkew = val;
+        break;
     case VIDMODE_V_DISPLAY:
-	((DisplayModePtr)mode)->VDisplay = val;
-	break;
+        ((DisplayModePtr) mode)->VDisplay = val;
+        break;
     case VIDMODE_V_SYNCSTART:
-	((DisplayModePtr)mode)->VSyncStart = val;
-	break;
+        ((DisplayModePtr) mode)->VSyncStart = val;
+        break;
     case VIDMODE_V_SYNCEND:
-	((DisplayModePtr)mode)->VSyncEnd = val;
-	break;
+        ((DisplayModePtr) mode)->VSyncEnd = val;
+        break;
     case VIDMODE_V_TOTAL:
-	((DisplayModePtr)mode)->VTotal = val;
-	break;
+        ((DisplayModePtr) mode)->VTotal = val;
+        break;
     case VIDMODE_FLAGS:
-	((DisplayModePtr)mode)->Flags = val;
-	break;
+        ((DisplayModePtr) mode)->Flags = val;
+        break;
     case VIDMODE_CLOCK:
-	((DisplayModePtr)mode)->Clock = val;
-	break;
-  }
-  return;
+        ((DisplayModePtr) mode)->Clock = val;
+        break;
+    }
+    return;
 }
 
 vidMonitorValue
-VidModeGetMonitorValue(pointer monitor, int valtyp, int indx)
+VidModeGetMonitorValue(void *monitor, int valtyp, int indx)
 {
-  vidMonitorValue ret;
-  
-  switch (valtyp) {
+    vidMonitorValue ret = { NULL, };
+
+    switch (valtyp) {
     case VIDMODE_MON_VENDOR:
-	ret.ptr = (((MonPtr)monitor)->vendor);
-	break;
+        ret.ptr = (((MonPtr) monitor)->vendor);
+        break;
     case VIDMODE_MON_MODEL:
-	ret.ptr = (((MonPtr)monitor)->model);
-	break;
+        ret.ptr = (((MonPtr) monitor)->model);
+        break;
     case VIDMODE_MON_NHSYNC:
-	ret.i = ((MonPtr)monitor)->nHsync;
-	break;
+        ret.i = ((MonPtr) monitor)->nHsync;
+        break;
     case VIDMODE_MON_NVREFRESH:
-	ret.i = ((MonPtr)monitor)->nVrefresh;
-	break;
+        ret.i = ((MonPtr) monitor)->nVrefresh;
+        break;
     case VIDMODE_MON_HSYNC_LO:
-	ret.f = (100.0 * ((MonPtr)monitor)->hsync[indx].lo);
-	break;
+        ret.f = (100.0 * ((MonPtr) monitor)->hsync[indx].lo);
+        break;
     case VIDMODE_MON_HSYNC_HI:
-	ret.f = (100.0 * ((MonPtr)monitor)->hsync[indx].hi);
-	break;
+        ret.f = (100.0 * ((MonPtr) monitor)->hsync[indx].hi);
+        break;
     case VIDMODE_MON_VREFRESH_LO:
-	ret.f = (100.0 * ((MonPtr)monitor)->vrefresh[indx].lo);
-	break;
+        ret.f = (100.0 * ((MonPtr) monitor)->vrefresh[indx].lo);
+        break;
     case VIDMODE_MON_VREFRESH_HI:
-	ret.f = (100.0 * ((MonPtr)monitor)->vrefresh[indx].hi);
-	break;
-  }
-  return ret;
+        ret.f = (100.0 * ((MonPtr) monitor)->vrefresh[indx].hi);
+        break;
+    }
+    return ret;
 }
 
-
-#endif /* XF86VIDMODE */
+#endif                          /* XF86VIDMODE */
